<?php
use Bitrix\Main\Config\Option;
use Bitrix\Main\Localization\Loc;
use Bitrix\Main\Web\Json;

Loc::loadMessages(__FILE__);

$request = \Bitrix\Main\Application::getInstance()->getContext()->getRequest();
$proto   = $request->isHttps() ? 'https' : 'http';

$promocodes = Option::get('tinkoff.creditbroker', 'promocodes');
if ($promocodes) {
	$promocodes = Json::decode($promocodes);
} else {
	$promocodes = [];
}

$promoOptions = [];
$iterator     = 1000;
foreach ($promocodes as $promocode => $promoTitle) {
	$promoOptions['TCB_PROMOCODE_' . strtoupper($promocode)] = [
		'NAME'        => $promoTitle,
		"DESCRIPTION" => '',
		'SORT'        => $iterator++,
		'INPUT'       => [
			'TYPE' => 'Y/N',
		],
		'DEFAULT'     => [
			'PROVIDER_KEY'   => 'INPUT',
			'PROVIDER_VALUE' => 'Y',
		],
		'GROUP'       => Loc::getMessage("TINKOFF.CREDITBROKER_GROUP_PROMOCODES"),
	];
}

$description = [
	'MAIN' => Loc::getMessage('TINKOFF.CREDITBROKER_PAYMENT_DESCRIPTION'),
];

$data = [
	'NAME'  => Loc::getMessage('TINKOFF.CREDITBROKER_PAYMENT_TITLE'),
	'SORT'  => 500,
	'CODES' => [
		'ORDER_NUMBER'    => [
			'NAME'    => Loc::getMessage('TINKOFF.CREDITBROKER_OPTIONS_ORDER_NUMBER'),
			'SORT'    => 1000,
			'DEFAULT' => [
				'PROVIDER_VALUE' => 'ACCOUNT_NUMBER',
				'PROVIDER_KEY'   => 'ORDER',
			],
			'GROUP'   => Loc::getMessage("TINKOFF.CREDITBROKER_GROUP_OTHER"),
		],

		'TCB_SHOP_ID'     => [
			'NAME'        => Loc::getMessage('TINKOFF.CREDITBROKER_OPTIONS_SHOP_ID'),
			"DESCRIPTION" => Loc::getMessage("TINKOFF.CREDITBROKER_OPTIONS_SHOP_ID_DESC"),
			'SORT'        => 200,
			'GROUP'       => Loc::getMessage("TINKOFF.CREDITBROKER_GROUP_SETTINGS"),
		],
		'TCB_SHOWCASE_ID' => [
			'NAME'        => Loc::getMessage('TINKOFF.CREDITBROKER_OPTIONS_SHOWCASE_ID'),
			"DESCRIPTION" => Loc::getMessage("TINKOFF.CREDITBROKER_OPTIONS_SHOWCASE_ID_DESC"),
			'SORT'        => 300,
			'GROUP'       => Loc::getMessage("TINKOFF.CREDITBROKER_GROUP_SETTINGS"),
		],
		'TCB_PASSWORD'    => [
			'NAME'        => Loc::getMessage('TINKOFF.CREDITBROKER_OPTIONS_PASSWORD'),
			"DESCRIPTION" => Loc::getMessage("TINKOFF.CREDITBROKER_OPTIONS_PASSWORD_DESC"),
			'SORT'        => 350,
			'GROUP'       => Loc::getMessage("TINKOFF.CREDITBROKER_GROUP_SETTINGS"),
		],
		'TCB_SUCCESS_URL' => [
			'NAME'        => Loc::getMessage('TINKOFF.CREDITBROKER_OPTIONS_SUCCESS_URL'),
			"DESCRIPTION" => Loc::getMessage("TINKOFF.CREDITBROKER_OPTIONS_SUCCESS_URL_DESC"),
			'SORT'        => 500,
			'DEFAULT'     => [
				'PROVIDER_KEY'   => 'VALUE',
				'PROVIDER_VALUE' => $proto . '://' . $request->getHttpHost() . '/personal/orders/#ORDER_NUMBER#',
			],
			'GROUP'       => Loc::getMessage("TINKOFF.CREDITBROKER_GROUP_OTHER"),
		],
		'TCB_FAIL_URL'    => [
			'NAME'        => Loc::getMessage('TINKOFF.CREDITBROKER_OPTIONS_FAIL_URL'),
			"DESCRIPTION" => Loc::getMessage("TINKOFF.CREDITBROKER_OPTIONS_FAIL_URL_DESC"),
			'SORT'        => 600,
			'DEFAULT'     => [
				'PROVIDER_KEY'   => 'VALUE',
				'PROVIDER_VALUE' => $proto . '://' . $request->getHttpHost() . '/personal/orders/#ORDER_NUMBER#',
			],
			'GROUP'       => Loc::getMessage("TINKOFF.CREDITBROKER_GROUP_OTHER"),
		],
		'TCB_RETURN_URL'  => [
			'NAME'        => Loc::getMessage('TINKOFF.CREDITBROKER_OPTIONS_RETURN_URL'),
			"DESCRIPTION" => Loc::getMessage("TINKOFF.CREDITBROKER_OPTIONS_RETURN_URL_DESC"),
			'SORT'        => 650,
			'DEFAULT'     => [
				'PROVIDER_KEY'   => 'VALUE',
				'PROVIDER_VALUE' => $proto . '://' . $request->getHttpHost() . '/personal/orders/#ORDER_NUMBER#',
			],
			'GROUP'       => Loc::getMessage("TINKOFF.CREDITBROKER_GROUP_OTHER"),
		],
		'TCB_PAYMENT_PATH'  => [
			'NAME'        => Loc::getMessage('TINKOFF.CREDITBROKER_OPTIONS_PAYMENT_PATH'),
			"DESCRIPTION" => Loc::getMessage("TINKOFF.CREDITBROKER_OPTIONS_PAYMENT_PATH_DESC"),
			'SORT'        => 670,
			'DEFAULT'     => [
				'PROVIDER_KEY'   => 'VALUE',
				'PROVIDER_VALUE' => '/personal/order/payment/',
			],
			'GROUP'       => Loc::getMessage("TINKOFF.CREDITBROKER_GROUP_OTHER"),
		],
		'TCB_DEMO'        => [
			'NAME'        => Loc::getMessage('TINKOFF.CREDITBROKER_OPTIONS_DEMO'),
			"DESCRIPTION" => Loc::getMessage("TINKOFF.CREDITBROKER_OPTIONS_DEMO_DESC"),
			'SORT'        => 700,
			'INPUT'       => [
				'TYPE' => 'Y/N',
			],
			'DEFAULT'     => [
				'PROVIDER_KEY'   => 'INPUT',
				'PROVIDER_VALUE' => 'Y',
			],
			'GROUP'       => Loc::getMessage("TINKOFF.CREDITBROKER_GROUP_DEMO"),
		],
		'TCB_DEMO_FLOW'   => [
			'NAME'        => Loc::getMessage('TINKOFF.CREDITBROKER_OPTIONS_DEMO_FLOW'),
			"DESCRIPTION" => Loc::getMessage("TINKOFF.CREDITBROKER_OPTIONS_DEMO_FLOW_DESC"),
			'SORT'        => 800,
			"INPUT"       => [
				'TYPE'    => 'ENUM',
				'OPTIONS' => [
					'sms'                => Loc::getMessage("TINKOFF.CREDITBROKER_OPTIONS_DEMO_FLOW_SMS"),
					'appointment'        => Loc::getMessage("TINKOFF.CREDITBROKER_OPTIONS_DEMO_FLOW_APPOINTMENT"),
					'reject'             => Loc::getMessage("TINKOFF.CREDITBROKER_OPTIONS_DEMO_FLOW_REJECT"),
					'appointment-reject' => Loc::getMessage("TINKOFF.CREDITBROKER_OPTIONS_DEMO_FLOW_APPOINTMENT-REJECT"),
				],
			],
			'GROUP'       => Loc::getMessage("TINKOFF.CREDITBROKER_GROUP_DEMO"),
		],
	],
];

if (!empty($promoOptions)) {
	$data['CODES'] += $promoOptions;
}
