<?php

namespace Tinkoff\CreditBroker;

class Client
{

	protected $url = 'https://forma.tinkoff.ru/api/partners/v2/orders/';

	protected $shopId;
	protected $showcaseId;
	protected $password;
	protected $demo;

	public function __construct(string $shopId, string $showcaseId, string $password)
	{
		$this->shopId     = $shopId;
		$this->showcaseId = $showcaseId;
		$this->password   = $password;
		$this->demo       = false;
	}

	public function setDemoMode()
	{
		$this->demo = true;
	}

	public function create($data)
	{
		if ($this->demo) {
			return $this->request('create-demo', $data, false);
		}
		return $this->request('create', $data, false);
	}

	public function info($orderNumber)
	{
		$orderNumber = urlencode($orderNumber);
		return $this->request("{$orderNumber}/info");
	}

	public function commit($orderNumber)
	{
		return $this->request("{$orderNumber}/commit");
	}

	public function cancel($orderNumber)
	{
		return $this->request("{$orderNumber}/cancel");
	}

	protected function request(string $action, $data = [], bool $basicAuth = true)
	{
		$headers = [
			"Content-Type: application/json",

		];

		if ($basicAuth) {
			$login = $this->showcaseId;
			if ($this->demo) {
				$login = 'demo-' . $login;
			}
			$headers[] = "Authorization: Basic " . base64_encode("{$login}:{$this->password}");
		}

		if (!function_exists("curl_init")) {
			throw new \Exception("Curl error");
		}
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $this->url . $action);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 2);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, true);

		curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
		if (!empty($data)) {
			$encodedData = $this->encode($data);
			curl_setopt($ch, CURLOPT_POST, true);
			curl_setopt($ch, CURLOPT_POSTFIELDS, $encodedData);
		}

		$out = curl_exec($ch);

		$curlError = curl_error($ch);
		if ($curlError) {
			throw new Exceptions\ApiException($curlError);
		}


		$code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
		curl_close($ch);
		$response = json_decode($out, true);
		if ($code == 200) {
			return $response;
		}

		$error = 'Error: ' . $code;

		if (!empty($response['errors'])) {
			$error .= '. ' . implode(';', $response['errors']);
		}

		if (!empty($response['validations'])) {
			$list = array_map(
				function($key, $value){return "$key - $value";},
				array_keys($response['validations']),
				array_values($response['validations'])
			);
			$error .= ': '.implode($list);
		}

		if (!$response) {
			$error .= $out;
		}
		switch ($code) {
			case 400:
				$exception = new Exceptions\BadRequestException($error, $code);
				break;
			case 401:
				$exception = new Exceptions\AuthenticationException($error, $code);
				break;
			case 403:
				$exception = new Exceptions\AuthorizationException($error, $code);
				break;
			case 404:
				$exception = new Exceptions\NotFoundException($error, $code);
				break;
			case 422:
				$exception = new Exceptions\UnprocessableEntityException($error, $code);
				break;
			case 500:
				$exception = new Exceptions\InternalServerError($error, $code);
				break;
			default:
				$exception = new Exceptions\ApiException($error, $code);
				break;
		}
		throw $exception;
	}

	protected function encode($data)
	{
		if (is_string($data)) {
			return $data;
		}
		$result = json_encode($data);
		$error  = json_last_error();
		if ($error != JSON_ERROR_NONE) {
			throw new \Exception(json_last_error_msg());
		}
		return $result;
	}

	public static function clearPhone(string $phone)
	{
		$phone = preg_replace("/[^0-9]/", "", $phone);
		if (!preg_match("#[7|8]{0,1}(\d{10})#", $phone, $match)) {
			return '';
		}
		return $match[1];
	}
}
